@@ -1362,8 +1362,8 @@ id3_get_ufid_type (const gchar *name)
 static void
 extract_txxx_tags (id3v2tag *tag, const gchar *data, guint pos, size_t csize, id3tag *info, gfloat version)
 {
-	gchar *description;
-	gchar *value;
+	gchar *description = NULL;
+	gchar *value = NULL;
 	gchar text_encode;
 	const gchar *text_desc;
 	const gchar *text;
@@ -1381,11 +1381,11 @@ extract_txxx_tags (id3v2tag *tag, const gchar *data, guint pos, size_t csize, id
 	if (version == 2.3f) {
 		description = id3v2_text_to_utf8 (data[pos], &data[pos + 1], csize - 1, info);
 		value = id3v2_text_to_utf8 (text_encode, text, csize - offset, info);
-	}
-	else if (version == 2.4f) {
+	} else if (version == 2.4f) {
 		description = id3v24_text_to_utf8 (data[pos], &data[pos + 1], csize - 1, info);
 		value = id3v24_text_to_utf8 (text_encode, text, csize - offset, info);
 	}
+
 	if (!tracker_is_empty_string (description)) {
 		g_strstrip (description);
 		txxxtype = id3_get_txxx_type (description);
@@ -1402,6 +1402,7 @@ extract_txxx_tags (id3v2tag *tag, const gchar *data, guint pos, size_t csize, id
 		g_free (value);
 		return;
 	}
+
 	switch (txxxtype) {
 	case ACOUSTID_FINGERPRINT:
 		tag->acoustid_fingerprint = value;
@@ -2726,34 +2727,27 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 
 		md.album = tracker_resource_get_first_relation (album_disc, "nmm:albumDiscAlbum");
 
-		tracker_resource_set_relation (main_resource, "nmm:musicAlbum", md.album);
-		tracker_resource_set_relation (main_resource, "nmm:musicAlbumDisc", album_disc);
+		tracker_resource_set_take_relation (main_resource, "nmm:musicAlbumDisc", album_disc);
 
 		if (md.mb_release_id) {
 			mb_release_id = tracker_extract_new_external_reference("https://musicbrainz.org/doc/Release",
-									       md.mb_release_id);
+			                                                       md.mb_release_id);
 
-			tracker_resource_set_relation (md.album, "tracker:hasExternalReference", mb_release_id);
+			tracker_resource_set_take_relation (md.album, "tracker:hasExternalReference", mb_release_id);
 		}
 
 		if (md.mb_release_group_id) {
 			mb_release_group_id = tracker_extract_new_external_reference("https://musicbrainz.org/doc/Release_Group",
-									 	     md.mb_release_group_id);
+			                                                             md.mb_release_group_id);
 
-			if (mb_release_id) {
-				tracker_resource_add_relation (md.album, "tracker:hasExternalReference", mb_release_group_id);
-			} else
-				tracker_resource_set_relation (md.album, "tracker:hasExternalReference", mb_release_group_id);
+			tracker_resource_add_take_relation (md.album, "tracker:hasExternalReference", mb_release_group_id);
 		}
 
 		if (md.track_count > 0) {
 			tracker_resource_set_int (md.album, "nmm:albumTrackCount", md.track_count);
 		}
 
-		g_object_unref (album_disc);
 		g_clear_object (&album_artist);
-		g_object_unref (mb_release_id);
-		g_object_unref (mb_release_group_id);
 	}
 
 	tracker_resource_add_uri (main_resource, "rdf:type", "nmm:MusicPiece");
@@ -2776,7 +2770,7 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 			TrackerResource *mb_artist_id = tracker_extract_new_external_reference("https://musicbrainz.org/doc/Artist",
 											       md.mb_artist_id);
 
-			tracker_resource_set_relation (md.performer, "tracker:hasExternalReference", mb_artist_id);
+			tracker_resource_add_relation (md.performer, "tracker:hasExternalReference", mb_artist_id);
 			g_object_unref (mb_artist_id);
 		}
 	}
@@ -2824,7 +2818,7 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 		TrackerResource *mb_recording_id = tracker_extract_new_external_reference("https://musicbrainz.org/doc/Recording",
 											  md.mb_recording_id);
 
-		tracker_resource_set_relation (main_resource, "tracker:hasExternalReference", mb_recording_id);
+		tracker_resource_add_relation (main_resource, "tracker:hasExternalReference", mb_recording_id);
 		g_object_unref (mb_recording_id);
 	}
 
@@ -2832,12 +2826,7 @@ tracker_extract_get_metadata (TrackerExtractInfo *info)
 		TrackerResource *mb_track_id = tracker_extract_new_external_reference("https://musicbrainz.org/doc/Track",
 										      md.mb_track_id);
 
-		if (md.mb_recording_id) {
-			tracker_resource_add_relation (main_resource, "tracker:hasExternalReference", mb_track_id);
-		} else {
-			tracker_resource_set_relation (main_resource, "tracker:hasExternalReference", mb_track_id);
-		}
-
+		tracker_resource_add_relation (main_resource, "tracker:hasExternalReference", mb_track_id);
 		g_object_unref (mb_track_id);
 	}
 
